# -*- coding: utf-8 -*-
'''
    :codeauthor: :email:`Pedro Algarvio (pedro@algarvio.me)`
    :copyright: © 2016 by the SaltStack Team, see AUTHORS for more details.
    :license: Apache 2.0, see LICENSE for more details.


    pytest_helpers_namespace.version
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    pytest helpers-namespace plugin version information
'''
# pragma: no cover

# Import Python Libs
from __future__ import absolute_import


__version_info__ = (2016, 4, 5)
__version__ = '{0}.{1}.{2}'.format(*__version_info__)
